package
Version:
v0.0.0-...-1661e1d
Opens a new window with list of versions in this module.
Published: Nov 25, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Output interface {
Print(i ...interface{})
Println(i ...interface{})
Printf(format string, i ...interface{})
PrintErr(i ...interface{})
PrintErrln(i ...interface{})
PrintErrf(format string, i ...interface{})
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.